#!/bin/sh
# This file has been automatically generated by cygbuild
#
# Please do not remove section comments '#:<name>'

set -e

PATH=/bin:/sbin:/usr/bin:/usr/sbin
LC_ALL=C

dest=$1


#:info
(
    cd /usr/share/info &&
    for i in  msmtp.info
    do
        install-info --dir-file=./dir --info-file=$i
    done
)
